@@ -15,12 +15,9 @@ __date__ = "Jun 1, 2012"
 
 import unittest
 import random
-from custodian.custodian import Job, ErrorHandler, Custodian, ScratchDir, \
-    recursive_copy
+from custodian.custodian import Job, ErrorHandler, Custodian
 import os
 import glob
-import tempfile
-import shutil
 
 
 class ExampleJob(Job):
@@ -44,10 +41,6 @@ class ExampleJob(Job):
     def name(self):
         return "ExampleJob{}".format(self.jobid)
 
-    @property
-    def to_dict(self):
-        return {"jobid": self.jobid}
-
     @staticmethod
     def from_dict(d):
         return ExampleJob(d["jobid"])
@@ -65,14 +58,6 @@ class ExampleHandler(ErrorHandler):
         self.params["initial"] += 1
         return {"errors": "total < 50", "actions": "increment by 1"}
 
-    @property
-    def is_monitor(self):
-        return False
-
-    @property
-    def to_dict(self):
-        return {}
-
     @staticmethod
     def from_dict(d):
         return ExampleHandler()
@@ -92,14 +77,6 @@ class ExampleHandler2(ErrorHandler):
     def correct(self):
         return {"errors": "errored", "actions": None}
 
-    @property
-    def is_monitor(self):
-        return False
-
-    @property
-    def to_dict(self):
-        return {}
-
     @staticmethod
     def from_dict(d):
         return ExampleHandler()
@@ -119,6 +96,7 @@ class CustodianTest(unittest.TestCase):
                       max_errors=njobs, log_file=None)
         output = c.run()
         self.assertEqual(len(output), njobs)
+        print ExampleHandler(params).to_dict
 
     def test_unrecoverable(self):
         njobs = 100
@@ -137,43 +115,6 @@ class CustodianTest(unittest.TestCase):
         os.chdir(self.cwd)
 
 
-class FuncTest(unittest.TestCase):
-
-    def setUp(self):
-        self.cwd = os.getcwd()
-        os.chdir(os.path.abspath(os.path.dirname(__file__)))
-        os.mkdir("src")
-        with open(os.path.join("src", "test"), "w") as f:
-            f.write("what")
-
-    def test_recursive_copy(self):
-        recursive_copy(".", "dst")
-        self.assertTrue(os.path.exists(os.path.join("dst", "src", "test")))
-        self.assertTrue(os.path.exists(os.path.join("dst", "__init__.py")))
-
-    def tearDown(self):
-        shutil.rmtree("src")
-        shutil.rmtree("dst")
-        os.chdir(self.cwd)
-
-
-class ScratchDirTest(unittest.TestCase):
-
-    def test_with(self):
-        scratch = tempfile.gettempdir()
-        with ScratchDir(scratch) as d:
-            with open("scratch_text", "w") as f:
-                f.write("write")
-            files = os.listdir(d)
-            self.assertIn("scratch_text", files)
-
-        #Make sure the tempdir is deleted.
-        self.assertFalse(os.path.exists(d))
-        files = os.listdir(".")
-        self.assertIn("scratch_text", files)
-        os.remove("scratch_text")
-
-
 if __name__ == "__main__":
     #import sys;sys.argv = ['', 'Test.testName']
     unittest.main()
